Project Info Name.......: gnu-hello
Description: GNU Hello


gnu-hello       
Info
Commit...:665e4942ded6d5ff70badf74fe0f6064c686d5fb
Author...:karl <>
Committer:karl <>
Date.....:Thu Jul 26 17:12:57 2007 +0000
Parents..:235171fde82107ed85592ca66f9f97989c8509b1

Message
[project @ 2007-07-26 17:12:56 by karl]
gnulib update

Changes
diff --git a/gnulib/lib/Makefile.am b/gnulib/lib/Makefile.am
line changes: +15/-0
index 21e449e..e15d2ee
--- a/gnulib/lib/Makefile.am
+++ b/gnulib/lib/Makefile.am
@@ -119,6 +119,8 @@ EXTRA_libgnu_a_SOURCES += getopt.c getopt1.c
 # "gettextize --intl".
 AM_CPPFLAGS += -I$(top_builddir)/intl
 
+EXTRA_DIST += $(top_srcdir)/build-aux/config.rpath
+
 ## end   gnulib module gettext
 
 ## begin gnulib module gettext-h
@@ -127,10 +129,19 @@ libgnu_a_SOURCES += gettext.h
 
 ## end   gnulib module gettext-h
 
+## begin gnulib module havelib
+
+
+EXTRA_DIST += $(top_srcdir)/build-aux/config.rpath
+
+## end   gnulib module havelib
+
 ## begin gnulib module link-warning
 
 LINK_WARNING_H=$(top_srcdir)/build-aux/link-warning.h
 
+EXTRA_DIST += $(top_srcdir)/build-aux/link-warning.h
+
 ## end   gnulib module link-warning
 
 ## begin gnulib module quotearg
@@ -240,6 +251,10 @@ wchar.h: wchar_.h
 	  sed -e 's/@''INCLUDE_NEXT''@/$(INCLUDE_NEXT)/g' \
 	      -e 's|@''NEXT_WCHAR_H''@|$(NEXT_WCHAR_H)|g' \
 	      -e 's/@''HAVE_WCHAR_H''@/$(HAVE_WCHAR_H)/g' \
+	      -e 's|@''GNULIB_WCWIDTH''@|$(GNULIB_WCWIDTH)|g' \
+	      -e 's|@''HAVE_DECL_WCWIDTH''@|$(HAVE_DECL_WCWIDTH)|g' \
+	      -e 's|@''REPLACE_WCWIDTH''@|$(REPLACE_WCWIDTH)|g' \
+	      -e '/definition of GL_LINK_WARNING/r $(LINK_WARNING_H)' \
 	    < $(srcdir)/wchar_.h; \
 	} > $@-t
 	mv $@-t $@

diff --git a/gnulib/lib/error.c b/gnulib/lib/error.c
line changes: +2/-1
index cf86343..9cf67ff
--- a/gnulib/lib/error.c
+++ b/gnulib/lib/error.c
@@ -1,5 +1,5 @@
 /* Error handler for noninteractive utilities
-   Copyright (C) 1990-1998, 2000-2005, 2006 Free Software Foundation, Inc.
+   Copyright (C) 1990-1998, 2000-2007 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    This program is free software; you can redistribute it and/or modify
@@ -31,6 +31,7 @@
 
 #if !_LIBC && ENABLE_NLS
 # include "gettext.h"
+# define _(msgid) gettext (msgid)
 #endif
 
 #ifdef _LIBC

diff --git a/gnulib/lib/wchar_.h b/gnulib/lib/wchar_.h
line changes: +34/-1
index 1d52b1d..924a338
--- a/gnulib/lib/wchar_.h
+++ b/gnulib/lib/wchar_.h
@@ -22,7 +22,8 @@
  * ISO C 99 <wchar.h> for platforms that have issues.
  * <http://www.opengroup.org/susv3xbd/wchar.h.html>
  *
  * For now, this just ensures proper prerequisite inclusion order.
  */
 
 #ifndef _GL_WCHAR_H
@@ -45,5 +46,37 @@
 #ifndef _GL_WCHAR_H
 #define _GL_WCHAR_H
 
+/* The definition of GL_LINK_WARNING is copied here.  */
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+
+/* Return the number of screen columns needed for WC.  */
+#if @GNULIB_WCWIDTH@
+# if @REPLACE_WCWIDTH@
+#  undef wcwidth
+#  define wcwidth rpl_wcwidth
+extern int wcwidth (wchar_t);
+# else
+#  if !defined wcwidth && !@HAVE_DECL_WCWIDTH@
+/* wcwidth exists but is not declared.  */
+extern int wcwidth (int /* actually wchar_t */);
+#  endif
+# endif
+#elif defined GNULIB_POSIXCHECK
+# undef wcwidth
+# define wcwidth(w) \
+    (GL_LINK_WARNING ("wcwidth is unportable - " \
+                      "use gnulib module wcwidth for portability"), \
+     wcwidth (w))
+#endif
+
+
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* _GL_WCHAR_H */
 #endif /* _GL_WCHAR_H */
@@ -22,7 +22,8 @@
  * <http://www.opengroup.org/susv3xbd/wchar.h.html>
  *
- * For now, this just ensures proper prerequisite inclusion order.
+ * For now, this just ensures proper prerequisite inclusion order and
+ * the declaration of wcwidth().
  */
 

This website is licensed under AGPL-3.0. Feel free to copy!